@@ -1,17 +1,47 @@
-
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::dumpphases::Role::Theme::SimpleColor;
-BEGIN {
-  $Dist::Zilla::dumpphases::Role::Theme::SimpleColor::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::dumpphases::Role::Theme::SimpleColor::VERSION = '0.6.0';
-}
-use Role::Tiny;
+
+our $VERSION = '1.000000';
 
 # ABSTRACT: A role for themes that are simple single-color themes with variations of bold/uncolored.
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Role::Tiny qw( requires );
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -59,18 +89,39 @@ sub _color_plugin_star {
 }
 
 
+
+
+
+
+
+
+
 sub print_section_header {
   my ( $self, $label, $comment ) = @_;
   return printf "\n%s%s\n", $self->_color_label_label($label), $self->_color_label_value($comment);
 }
 
 
+
+
+
+
+
+
+
 sub print_section_prelude {
   my ( $self, $label, $value ) = @_;
   return printf "%s%s\n", $self->_color_attribute_label( ' - ' . $label ), $self->_color_attribute_value($value);
 }
 
 
+
+
+
+
+
+
+
 sub print_star_assoc {
   my ( $self, $name, $value ) = @_;
   return printf "%s%s%s\n",
@@ -93,7 +144,7 @@ Dist::Zilla::dumpphases::Role::Theme::SimpleColor - A role for themes that are s
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -166,7 +217,7 @@ Oliver Mengué <dolmen@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
