@@ -1,22 +1,47 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::dumpphases::Theme::basic::blue;
-BEGIN {
-  $Dist::Zilla::dumpphases::Theme::basic::blue::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::dumpphases::Theme::basic::blue::VERSION = '0.6.0';
-}
 
-# ABSTRACT: A blue color theme for C<dzil dumpphases>
+our $VERSION = '1.000000';
+
+# ABSTRACT: A blue color theme for dzil dumpphases
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
-use Moo;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Moo qw( with );
 
 with 'Dist::Zilla::dumpphases::Role::Theme::SimpleColor';
 
 
+
+
+
+
+
+
+
 sub color { return 'blue' }
 
 1;
@@ -29,11 +54,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::dumpphases::Theme::basic::blue - A blue color theme for C<dzil dumpphases>
+Dist::Zilla::dumpphases::Theme::basic::blue - A blue color theme for dzil dumpphases
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -81,7 +106,7 @@ Oliver Mengué <dolmen@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
